<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR" sourcelanguage="en">
<context>
    <name>About</name>
    <message>
        <location filename="../../src/about.ui" line="17"/>
        <source>About KDiskMark</source>
        <translation>KDiskMark Hakkında</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="62"/>
        <source>Version:</source>
        <translation>Versiyon:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="88"/>
        <source>License:</source>
        <translation>Lisans:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="114"/>
        <source>Author:</source>
        <translation>Yazan:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="146"/>
        <source>E-mail:</source>
        <translation>E-posta:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="178"/>
        <source>Flexible I/O Tester:</source>
        <translation>Flexible I/O Tester:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="204"/>
        <source>Application Icon:</source>
        <translation>Uygulama Simgesi:</translation>
    </message>
</context>
<context>
    <name>Benchmark</name>
    <message>
        <location filename="../../src/benchmark.cpp" line="232"/>
        <source>Preparing...</source>
        <translation>Hazırlanıyor...</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="254"/>
        <source>Sequential Read %1/%2</source>
        <translation>Sıralı Okuma %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="264"/>
        <source>Sequential Write %1/%2</source>
        <translation>Sıralı Yazma %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="274"/>
        <source>Sequential Mix %1/%2</source>
        <translation>Sıraları Karışık %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="405"/>
        <source>Could not obtain administrator privileges.</source>
        <translation>Yönetici ayrıcalıkları elde edilemedi.</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="258"/>
        <source>Random Read %1/%2</source>
        <translation>Rastgele Okuma %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="268"/>
        <source>Random Write %1/%2</source>
        <translation>Rastgele Yazma %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="278"/>
        <source>Random Mix %1/%2</source>
        <translation>Rastgele Karışık %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="285"/>
        <source>Interval Time %1/%2 sec</source>
        <translation>Zaman Aralığı %1/%2 sec</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/mainwindow.ui" line="30"/>
        <location filename="../../src/mainwindow.cpp" line="917"/>
        <source>All</source>
        <translation>Hepsi</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="351"/>
        <location filename="../../src/mainwindow.ui" line="933"/>
        <location filename="../../src/mainwindow.cpp" line="547"/>
        <source>Read</source>
        <translation>Okuma</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="520"/>
        <location filename="../../src/mainwindow.ui" line="952"/>
        <location filename="../../src/mainwindow.cpp" line="550"/>
        <source>Write</source>
        <translation>Yazma</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="686"/>
        <location filename="../../src/mainwindow.cpp" line="553"/>
        <source>Mix</source>
        <translation>Karışık</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="220"/>
        <location filename="../../src/mainwindow.cpp" line="436"/>
        <location filename="../../src/mainwindow.cpp" line="440"/>
        <source>MB/s</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="225"/>
        <source>GB/s</source>
        <translation>GB/s</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="230"/>
        <location filename="../../src/mainwindow.cpp" line="442"/>
        <location filename="../../src/mainwindow.cpp" line="443"/>
        <source>IOPS</source>
        <translation>IOPS</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="235"/>
        <location filename="../../src/mainwindow.cpp" line="445"/>
        <location filename="../../src/mainwindow.cpp" line="446"/>
        <source>μs</source>
        <translation>μs</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1017"/>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1025"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1029"/>
        <source>Test Data</source>
        <translation>Sınama Verisi</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1047"/>
        <source>Profile</source>
        <translation>Profil</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1063"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1067"/>
        <source>Language</source>
        <translation>Dil</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1075"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1091"/>
        <source>About KDiskMark</source>
        <translation>KDiskMark Hakkında</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1096"/>
        <source>Queues &amp;&amp; Threads</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1101"/>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1106"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1111"/>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1122"/>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1130"/>
        <source>Peak Performance</source>
        <translation>En yüksek başarım</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1138"/>
        <source>Real World Performance</source>
        <translation>Gerçek dünya başarımı</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1146"/>
        <source>Default [+Mix]</source>
        <translation>Varsayılan [+Karışık]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1154"/>
        <source>Peak Performance [+Mix]</source>
        <translation>En yüksek başarım [+Karışık]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1162"/>
        <source>Real World Performance [+Mix]</source>
        <translation>Gerçek dünya başarımı [+Karışık]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1173"/>
        <source>Flush Pagecache</source>
        <translation>Disk önbelleğini boşalt</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1181"/>
        <source>Demo</source>
        <translation>Demo</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1192"/>
        <source>Read and Write [+Mix]</source>
        <translation>Okuma ve Yazma [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1200"/>
        <source>Read [+Mix]</source>
        <translation>Okuma [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1208"/>
        <source>Write [+Mix]</source>
        <translation>Yazma [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1219"/>
        <source>Random</source>
        <translation>Rastgele</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1227"/>
        <source>Fill with zeros</source>
        <translation>Sıfırlarla doldurun</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1238"/>
        <source>Standard Preset</source>
        <translation>Varsayılan ayarlar</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1246"/>
        <source>NVMe SSD</source>
        <translation>NVMe SSD</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1257"/>
        <source>Use Fusion</source>
        <translation>Fusion kullanın</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1265"/>
        <source>Stylesheet Light</source>
        <translation>Stil Sayfası Light</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1273"/>
        <source>Stylesheet Dark</source>
        <translation>Stil Sayfası Dark</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1281"/>
        <source>Do not apply</source>
        <translation>Kullanmayın</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1292"/>
        <source>Use O_DIRECT</source>
        <translation>O_DIRECT kullanın</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1303"/>
        <source>CoW detection</source>
        <translation>CoW algılama</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="54"/>
        <source>The device is encrypted. Performance may drop.</source>
        <translation>Aygıt şifrelenmiş. Performans düşüşebilir.</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="352"/>
        <location filename="../../src/mainwindow.cpp" line="452"/>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="356"/>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>Bytes</source>
        <translation>Bayt</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="452"/>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="263"/>
        <location filename="../../src/mainwindow.cpp" line="322"/>
        <source>Add a directory</source>
        <translation>Dizin ekle</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>PiB</source>
        <translation>PiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="892"/>
        <location filename="../../src/mainwindow.cpp" line="893"/>
        <location filename="../../src/mainwindow.cpp" line="894"/>
        <location filename="../../src/mainwindow.cpp" line="895"/>
        <location filename="../../src/mainwindow.cpp" line="896"/>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="944"/>
        <source>Stopping...</source>
        <translation>Durduruluyor...</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="954"/>
        <source>Not available</source>
        <translation>Mevcut Değil</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="954"/>
        <source>Directory is not specified.</source>
        <translation>Dizin belirlenmedi.</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="1059"/>
        <source>Copy-on-Write (CoW) is enabled on the selected directory.</source>
        <translation>Seçili dizinde yazma üzerine kopyalama (CoW) etkinleştirildi.</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="1060"/>
        <source>This may affect performance results. Would you like to create a new subdirectory with CoW disabled?</source>
        <translation>Bu, performans sonuçlarını etkileyebilir. CoW devre dışı bırakılmış yeni bir alt dizin oluşturmak ister misiniz?</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation type="vanished">Onay</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="964"/>
        <source>Benchmark Failed</source>
        <translation>Benchmark Başarısız oldu</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/global.cpp" line="25"/>
        <source>&lt;h2&gt;%1 %2 %3&lt;br/&gt;Queues=%4&lt;br/&gt;Threads=%5%6&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;%1 %2 %3&lt;br/&gt;Kuyruklar=%4&lt;br/&gt;İşlemler=%5%6&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="26"/>
        <source>Sequential</source>
        <translation>Sıralı</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="26"/>
        <source>Random</source>
        <translation>Rastgele</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="28"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="28"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="34"/>
        <source>&lt;h1&gt;%1 MB/s&lt;br/&gt;%2 GB/s&lt;br/&gt;%3 IOPS&lt;br/&gt;%4 μs&lt;/h1&gt;</source>
        <translation>&lt;h1&gt;%1 MB/s&lt;br/&gt;%2 GB/s&lt;br/&gt;%3 IOPS&lt;br/&gt;%4 μs&lt;/h1&gt;</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="200"/>
        <source>No FIO was found. Please install FIO before using KDiskMark.</source>
        <translation>FIO bulunamadı. KDiskMark&apos;ı kullanmadan önce FIO&apos;yu yükleyiniz.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../../src/settings.ui" line="14"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="149"/>
        <source>Block Size</source>
        <translation>Blok Boyutu</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="165"/>
        <source>Queues</source>
        <translation>Kuyruk Sayısı</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="181"/>
        <source>Threads</source>
        <translation>İşlem Sayısı</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="257"/>
        <source>Profile: Default</source>
        <translation>Profil: Varsayılan</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="280"/>
        <source>Type</source>
        <translation>Tür</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="335"/>
        <source>Profile: Peak Performance</source>
        <translation>Profil: En yüksek başarım</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="446"/>
        <source>Profile: Demo</source>
        <translation>Profil: Demo</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="508"/>
        <source>Measuring time</source>
        <translation>Ölçüm Zamanı</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="530"/>
        <source>Interval time</source>
        <translation>Zaman Aralığı</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="18"/>
        <location filename="../../src/settings.cpp" line="23"/>
        <source>sec</source>
        <translation>sn</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="19"/>
        <location filename="../../src/settings.cpp" line="24"/>
        <source>min</source>
        <translation>dk</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="71"/>
        <location filename="../../src/settings.cpp" line="72"/>
        <location filename="../../src/settings.cpp" line="73"/>
        <location filename="../../src/settings.cpp" line="74"/>
        <location filename="../../src/settings.cpp" line="76"/>
        <location filename="../../src/settings.cpp" line="77"/>
        <location filename="../../src/settings.cpp" line="79"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="59"/>
        <location filename="../../src/settings.cpp" line="60"/>
        <location filename="../../src/settings.cpp" line="61"/>
        <location filename="../../src/settings.cpp" line="62"/>
        <location filename="../../src/settings.cpp" line="64"/>
        <location filename="../../src/settings.cpp" line="65"/>
        <location filename="../../src/settings.cpp" line="67"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
</context>
</TS>
